changeset 12911:be0fe2c66b9d

Require rmail. (rmail-new-summary): Specify size in split-window. Call rmail-select-summary to force size to specified amount.
author Richard M. Stallman <rms@gnu.org>
date Mon, 21 Aug 1995 14:48:49 +0000
parents 8aa95606db04
children e519963ce31a
files lisp/mail/rmailsum.el
diffstat 1 files changed, 21 insertions(+), 12 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/mail/rmailsum.el	Mon Aug 21 14:30:34 1995 +0000
+++ b/lisp/mail/rmailsum.el	Mon Aug 21 14:48:49 1995 +0000
@@ -29,6 +29,9 @@
 
 ;;; Code:
 
+;; For rmail-select-summary
+(require 'rmail)
+
 (defvar rmail-summary-font-lock-keywords
   '(("^....D.*" . font-lock-string-face)			; Deleted.
     ("^....-.*" . font-lock-type-face)				; Unread.
@@ -206,18 +209,24 @@
       (setq rmail-summary-buffer sumbuf))
     ;; Now display the summary buffer and go to the right place in it.
     (or was-in-summary
-	(if (and (one-window-p)
-		 pop-up-windows (not pop-up-frames))
-	    ;; If there is just one window, put the summary on the top.
-	    (progn
-	      (split-window)
-	      (select-window (next-window (frame-first-window)))
-	      (pop-to-buffer sumbuf)
-	      ;; If pop-to-buffer did not use that window, delete that
-	      ;; window.  (This can happen if it uses another frame.)
-	      (if (not (eq sumbuf (window-buffer (frame-first-window))))
-		  (delete-other-windows)))
-	  (pop-to-buffer sumbuf)))
+	(progn
+	  (if (and (one-window-p)
+		   pop-up-windows (not pop-up-frames))
+	      ;; If there is just one window, put the summary on the top.
+	      (progn
+		(split-window (selected-window) rmail-summary-window-size)
+		(select-window (next-window (frame-first-window)))
+		(pop-to-buffer sumbuf)
+		;; If pop-to-buffer did not use that window, delete that
+		;; window.  (This can happen if it uses another frame.)
+		(if (not (eq sumbuf (window-buffer (frame-first-window))))
+		    (delete-other-windows)))
+	    (pop-to-buffer sumbuf))
+	  (set-buffer rmail-buffer)
+	  ;; This is how rmail makes the summary buffer reappear.
+	  ;; We do this here to make the window the proper size.
+	  (rmail-select-summary nil)
+	  (set-buffer rmail-summary-buffer)))
     (rmail-summary-goto-msg mesg t t)
     (rmail-summary-construct-io-menu)
     (message "Computing summary lines...done")))